==> bptf-0.1.0.tar.gz: bptf-0.1.0/README.md <==
# backpack-tf
[![Stars](https://img.shields.io/github/stars/offish/backpack-tf.svg)](https://github.com/offish/backpack-tf/stargazers)
[![Issues](https://img.shields.io/github/issues/offish/backpack-tf.svg)](https://github.com/offish/backpack-tf/issues)
[![Size](https://img.shields.io/github/repo-size/offish/backpack-tf.svg)](https://github.com/offish/backpack-tf)
[![Discord](https://img.shields.io/discord/467040686982692865?color=7289da&label=Discord&logo=discord)](https://discord.gg/t8nHSvA)
[![Downloads](https://img.shields.io/pypi/dm/backpack-tf)](https://pypi.org/project/backpack-tf/)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)


Create and manage Backpack.tf listings (API v2) using Python 3.

> [!TIP]
> Consider using tf2-utils' [ListingManager](https://github.com/offish/tf2-utils) instead of `backpack-tf` directly.

## Donate
- BTC: `bc1q9gmh5x2g9s0pw3282a5ypr6ms8qvuxh3fd7afh`
- [Steam Trade Offer](https://steamcommunity.com/tradeoffer/new/?partner=293059984&token=0-l_idZR)

## Setup
### Install
```bash
pip install bptf
# or 
python -m pip install bptf
```

### Updating
```bash
pip install --upgrade bptf
# or 
python -m pip install --upgrade bptf
```

## Usage 
See the [examples](/examples/) or use the [ListingManager in tf2-utils](https://github.com/offish/tf2-utils).

## Testing
```bash
# backpack-tf/
pytest
```

==> bptf-0.1.2.tar.gz: bptf-0.1.2/README.md <==
# backpack-tf
[![Stars](https://img.shields.io/github/stars/offish/backpack-tf.svg)](https://github.com/offish/backpack-tf/stargazers)
[![Issues](https://img.shields.io/github/issues/offish/backpack-tf.svg)](https://github.com/offish/backpack-tf/issues)
[![Size](https://img.shields.io/github/repo-size/offish/backpack-tf.svg)](https://github.com/offish/backpack-tf)
[![Discord](https://img.shields.io/discord/467040686982692865?color=7289da&label=Discord&logo=discord)](https://discord.gg/t8nHSvA)
[![Downloads](https://img.shields.io/pypi/dm/bptf)](https://pypi.org/project/bptf/)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)


Create and manage Backpack.tf listings (API v2) using Python 3.

> [!TIP]
> Consider using tf2-utils' [ListingManager](https://github.com/offish/tf2-utils) instead of `backpack-tf` directly.

## Donate
- BTC: `bc1q9gmh5x2g9s0pw3282a5ypr6ms8qvuxh3fd7afh`
- [Steam Trade Offer](https://steamcommunity.com/tradeoffer/new/?partner=293059984&token=0-l_idZR)

## Setup
### Install
```bash
pip install bptf
# or 
python -m pip install bptf
```

### Updating
```bash
pip install --upgrade bptf
# or 
python -m pip install --upgrade bptf
```

## Usage 
See the [examples](/examples/) or use the [ListingManager in tf2-utils](https://github.com/offish/tf2-utils).

## Testing
```bash
# backpack-tf/
pytest
```
